/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*
 * File: cbak\client\client.c
 *
 * This example runs in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * Client code for the callback example. This program produces the sum 
 * of the numbers given on the command line.  It does this using a remote 
 * procedure to add the elements of an array.
 * The array itself is not passed to the remote procedure. Rather, the
 * remote procedure 'sum_array' retrieves the elements of the array
 * using the callback facility being demonstrated here. When done, the
 * program shuts down the server by calling the remote procedure
 * 'stop_server'.
 */ 

#include <stdio.h>
#include "cbak.h"

/* Server_Name is used to set the process-binding variable.
 * It must be defined as the name the server registers under.
 */
#define Server_Name "example" 

/* declare variable of type server_name for process binding */
server_name	sname;

extern int _rpcerr_;	/* declare RPC error code */

int	array[10];
int	nitems = 10;

main()
{
	int	result, i;

	sname = Server_Name;

	for (i=1; i<=nitems; i++) array[i-1] = i;

	printf("CLIENT: calling sum_array (%d items)\n", nitems);

	result = sum_array(nitems);

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in sum_array() call\n",
			_rpcerr_);
		exit(1);
	}

	printf("CLIENT: sum_array returned %d\n", result);


	exit(0);
}

/*
 * get_element() - return the value of element 'n' in the array
 *
 * This procedure is called remotely from the server using the
 * callback facility.
 */
int
get_element(n)
int	n;
{
	printf("CLIENT: get_element(%d)\n", n);
	return (array[n]);
}
